==> eea.locationwidget-0.1.zip: eea.locationwidget-0.1/eea/locationwidget/skins/LocationWidget/locationwidget.js <==
var xmlhttp;

function trim(str)
{
  var ret;
  if(typeof(str) != "string") str = str + "";
  return str.replace(/(^\s+)|(\s+$)/gi, "");
}

function initXMLdoc() {
  xmlhttp = null;
  if (window.XMLHttpRequest) {
    xmlhttp=new XMLHttpRequest()
  }
  else if (window.ActiveXObject) {
    xmlhttp = new ActiveXObject("Microsoft.XMLHTTP");
  }
}


function loadXMLDoc(url, handler) {
  initXMLdoc();
  if (xmlhttp != null)
  {
    xmlhttp.onreadystatechange = handler;
    xmlhttp.open("GET", url, true);
    xmlhttp.send(null);
  }
}

function processRequest() {
  if (xmlhttp.readyState == 4) {
    if (xmlhttp.status == 200) {
      return true;
    } else {
      alert('There was a problem retrieving the XML data:\n' + xmlhttp.statusText);
      return false;
    }
  }
}

function createMarker(map, lat, lng, id, label, icon) {
  var point = new YGeoPoint(lat, lng);
  var marker = new YMarker(point, icon);
  marker.setSmartWindowColor("grey");
  YEvent.Capture(marker, EventsList.MouseClick, function() { marker.openSmartWindow(document.getElementById(id).innerHTML);});
  map.addOverlay(marker);
  return marker.id;
}

function createSimpleMarker(map, lat, lng, label, icon) {
  var point = new YGeoPoint(lat, lng);
  var marker = new YMarker(point, icon);
  marker.setSmartWindowColor("grey");
  marker.addAutoExpand(label);
  map.addOverlay(marker);
}

function getScrollXY() {
  var scrOfX = 0, scrOfY = 0;
  if( typeof( window.pageYOffset ) == 'number' ) {
    //Netscape compliant
    scrOfY = window.pageYOffset;
    scrOfX = window.pageXOffset;
  } else if( document.body && ( document.body.scrollLeft || document.body.scrollTop ) ) {
    //DOM compliant
    scrOfY = document.body.scrollTop;
    scrOfX = document.body.scrollLeft;
  } else if( document.documentElement && ( document.documentElement.scrollLeft || document.documentElement.scrollTop ) ) {
    //IE6 standards compliant mode
    scrOfY = document.documentElement.scrollTop;
    scrOfX = document.documentElement.scrollLeft;
  }
  return [scrOfX, scrOfY];
}

function showListEntry(mapid, id) {
  var marker = map.getMarkerObject(mapid);
  map.drawZoomAndCenter(marker.YGeoPoint, 1);
  var scrOfY = getScrollXY()[1];
  if (scrOfY > 220) window.scrollTo(0, 220);
  marker.openSmartWindow(document.getElementById(id).innerHTML);
}

function handlerLoad() {
  if (PointLat == 0.0 || PointLon == 0.0) {
    map.drawZoomAndCenter(MapLoc, MapZoom);
  } else {
    map.drawZoomAndCenter(new YGeoPoint(PointLat, PointLon), PointZoom);
    map.addMarker(map.getCenterLatLon());
  }

  YEvent.Capture(map, EventsList.MouseClick, reportPosition);
  function reportPosition(_e, _c){
    var mapCoordCenter = map.convertLatLonXY(map.getCenterLatLon());
    map.removeMarkersAll();
    var currentGeoPoint = new YGeoPoint( _c.Lat, _c.Lon );
    map.addMarker(currentGeoPoint);
    document.getElementById("longitude").value = _c.Lon;
    document.getElementById("latitude").value = _c.Lat;
  }
}

function findAddress() {
  mapCenterLoc = document.getElementById('address').value;
  if (mapCenterLoc == '<street address>, <city>, <country>') {
    mapCenterLoc = 'Kongens Nytorv 6, 1050 Copenhagen K, Denmark';
  }

  if (mapCenterLoc != '') {
    map.drawZoomAndCenter(mapCenterLoc, PointZoom);
    YEvent.Capture(map, map.getEventsList().endMapDraw, addCenterMarker);
  }
  function addCenterMarker() {
    map.removeMarkersAll();
    var mcenter = map.getCenterLatLon();
    map.addMarker(mcenter);
    document.getElementById("longitude").value = mcenter.Lon;
    document.getElementById("latitude").value = mcenter.Lat;
  }
}

function locationInfo(value) {
  if (value == '<street address>, <city>, <country>') {
    document.getElementById('address').value = ''
  }
}

==> eea.locationwidget-4.2.zip: eea.locationwidget-4.2/eea/locationwidget/skins/LocationWidget/locationwidget.js <==
var xmlhttp;

function trim(str)
{
  var ret;
  if(typeof(str) != "string"){
    str = str + "";
  }
  return str.replace(/(^\s+)|(\s+$)/gi, "");
}

function initXMLdoc() {
  xmlhttp = null;
  if (window.XMLHttpRequest) {
    xmlhttp=new XMLHttpRequest();
  }
  else if (window.ActiveXObject) {
    xmlhttp = new ActiveXObject("Microsoft.XMLHTTP");
  }
}


function loadXMLDoc(url, handler) {
  initXMLdoc();
  if (xmlhttp !== null){
    xmlhttp.onreadystatechange = handler;
    xmlhttp.open("GET", url, true);
    xmlhttp.send(null);
  }
}

function processRequest() {
  if (xmlhttp.readyState == 4) {
    if (xmlhttp.status == 200) {
      return true;
    } else {
      alert('There was a problem retrieving the XML data:\n' + xmlhttp.statusText);
      return false;
    }
  }
}

function createMarker(map, lat, lng, id, label, icon) {
  var point = new YGeoPoint(lat, lng);
  var marker = new YMarker(point, icon);
  marker.setSmartWindowColor("grey");
  YEvent.Capture(marker, EventsList.MouseClick, function() { marker.openSmartWindow(document.getElementById(id).innerHTML);});
  map.addOverlay(marker);
  return marker.id;
}

function createSimpleMarker(map, lat, lng, label, icon) {
  var point = new YGeoPoint(lat, lng);
  var marker = new YMarker(point, icon);
  marker.setSmartWindowColor("grey");
  marker.addAutoExpand(label);
  map.addOverlay(marker);
}

function getScrollXY() {
  var scrOfX = 0, scrOfY = 0;
  if( typeof( window.pageYOffset ) == 'number' ) {
    //Netscape compliant
    scrOfY = window.pageYOffset;
    scrOfX = window.pageXOffset;
  } else if( document.body && ( document.body.scrollLeft || document.body.scrollTop ) ) {
    //DOM compliant
    scrOfY = document.body.scrollTop;
    scrOfX = document.body.scrollLeft;
  } else if( document.documentElement && ( document.documentElement.scrollLeft || document.documentElement.scrollTop ) ) {
    //IE6 standards compliant mode
    scrOfY = document.documentElement.scrollTop;
    scrOfX = document.documentElement.scrollLeft;
  }
  return [scrOfX, scrOfY];
}

function showListEntry(mapid, id) {
  var marker = map.getMarkerObject(mapid);
  map.drawZoomAndCenter(marker.YGeoPoint, 1);
  var scrOfY = getScrollXY()[1];
  if (scrOfY > 220){
    window.scrollTo(0, 220);
  }
  marker.openSmartWindow(document.getElementById(id).innerHTML);
}

function handlerLoad() {
  if (PointLat === 0.0 || PointLon === 0.0) {
    map.drawZoomAndCenter(MapLoc, MapZoom);
  } else {
    map.drawZoomAndCenter(new YGeoPoint(PointLat, PointLon), PointZoom);
    map.addMarker(map.getCenterLatLon());
  }

  function reportPosition(_e, _c){
    var mapCoordCenter = map.convertLatLonXY(map.getCenterLatLon());
    map.removeMarkersAll();
    var currentGeoPoint = new YGeoPoint( _c.Lat, _c.Lon );
    map.addMarker(currentGeoPoint);
    document.getElementById("longitude").value = _c.Lon;
    document.getElementById("latitude").value = _c.Lat;
  }

  YEvent.Capture(map, EventsList.MouseClick, reportPosition);
}

function findAddress() {
  mapCenterLoc = document.getElementById('address').value;
  if (mapCenterLoc == '<street address>, <city>, <country>') {
    mapCenterLoc = 'Kongens Nytorv 6, 1050 Copenhagen K, Denmark';
  }

  function addCenterMarker() {
    map.removeMarkersAll();
    var mcenter = map.getCenterLatLon();
    map.addMarker(mcenter);
    document.getElementById("longitude").value = mcenter.Lon;
    document.getElementById("latitude").value = mcenter.Lat;
  }

  if (mapCenterLoc !== '') {
    map.drawZoomAndCenter(mapCenterLoc, PointZoom);
    YEvent.Capture(map, map.getEventsList().endMapDraw, addCenterMarker);
  }

}

function locationInfo(value) {
  if (value == '<street address>, <city>, <country>') {
    document.getElementById('address').value = '';
  }
}
